pub async fn session_state_async(paths: &SessionPaths) -> Result<SessionState>Expand description
Probe a muxr session socket without starting a nested Tokio runtime.
Errors
- The probe runtime IO fails after connecting to the socket.
pub async fn session_state_async(paths: &SessionPaths) -> Result<SessionState>Probe a muxr session socket without starting a nested Tokio runtime.